@@ -3,8 +3,10 @@
 set -o xtrace -o nounset -o pipefail -o errexit
 
 # build statically linked binary with Rust
-cargo build   --release
-cargo install --root "$PREFIX" --path .
+cargo install --locked --root "$PREFIX" --path .
 
 # strip debug symbols
-strip "$PREFIX/bin/hexyl"
+"$STRIP" "$PREFIX/bin/hexyl"
+
+# remove extra build file
+rm -f "${PREFIX}/.crates.toml"
